@@ -15,6 +15,7 @@ ci_loader_conf = {
                 "BITBUCKET_STEP_UUID",
             ],
         },
+        "tag": "BITBUCKET_TAG",
     },
     "github": {
         # REF https://docs.github.com/en/actions/learn-github-actions/environment-variables
@@ -29,6 +30,7 @@ ci_loader_conf = {
                 "GITHUB_RUN_ID",
             ],
         },
+        "tag": "GITHUB_REF_NAME",
     },
     "gitlab": {
         # REF https://docs.gitlab.com/ee/ci/variables/predefined_variables.html
@@ -41,6 +43,7 @@ ci_loader_conf = {
                 "CI_JOB_URL",
             ],
         },
+        "tag": "CI_COMMIT_TAG",
     },
     "azure": {
         "commit": "BUILD_SOURCEVERSION",
@@ -84,6 +87,7 @@ def load(obj, env=None, silent=True, key=None, filename=None):
         ci_config_dict["commit"] = environ.get(ci_provider_env_cfg["commit"])
         ci_config_dict["branch"] = environ.get(ci_provider_env_cfg["branch"])
         ci_config_dict["pipeline_id"] = environ.get(ci_provider_env_cfg["pipeline_id"])
+        ci_config_dict["tag"] = environ.get(ci_provider_env_cfg["tag"])
 
         job_url_cnf = ci_provider_env_cfg["job_url"]
         ci_config_dict["job_url"] = job_url_cnf["format"].format(
