@@ -44,8 +44,8 @@ class CIRun:
             _logger.error("ERROR: No commit id envvar found")
             env_error = True
 
-        if self._settings.get("branch") is None:
-            _logger.error("ERROR: No branch name envvar found")
+        if self._settings.get("branch") is None and self._settings.get("tag") is None:
+            _logger.error("ERROR: No branch or tag name envvar found")
             env_error = True
 
         if self._settings.get("analysis_type") is None:
@@ -61,7 +61,11 @@ class CIRun:
 
         analysis_type = self._settings.analysis_type
         commit_id = self._settings.commit
-        branch_name = self._settings.branch
+        branch_name = (
+            self._settings.tag
+            if self._settings.get("branch") is None
+            else self._settings.branch
+        )
         pipeline_id = self._settings.get("pipeline_id")
         job_name = self._settings.get("job_name")
 
